@@ -168,7 +168,8 @@ class MainWindow(QtGui.QMainWindow):
         index=self.ui.platform.currentIndex()
         #print index
         setplatform=self.ui.platform.currentText()
-        setplayername=self.ui.playername.text() 
+        setplayername=str(self.ui.playername.text())
+        setplayername=setplayername.strip()
         if index!=int(3):
                 #print"Index not 3,...."
                 if setplatform=="Xbox 360":
